Package: bibtex
Version: 0.5.2
Title: Bibtex Parser
Authors@R: c(
    person(given = "Romain", 
           family = "Francois", 
           role = c("aut", "cph"), 
           email = "romain@purrple.cat",
           comment = c(ORCID = "0000-0002-2444-4226", "principal developer of bibtex R package")),
    person(given = "Diego", 
           family = "Hernangómez", 
           role = c("aut"), 
           email = "diego.hernangomezherrero@gmail.com",
           comment = c(ORCID = "0000-0001-8457-4658")),
    person(given = c("James", "Joseph"),
           family = "Balamuta",
           role = c("ctb", "cre", "aut"),
           email = "balamut2@illinois.edu",
           comment = c(ORCID = "0000-0003-2826-8458")),
    person(given = "Scott",
           family = "Chamberlain",
           role = c("ctb"),
           email = "myrmecocystus@gmail.com",
           comment = c(ORCID = "0000-0003-1444-9135")),
    person(given = "Kurt", 
           family = "Hornik", 
           role = "ctb", 
           email = "Kurt.Hornik@R-project.org",
           comment = c(ORCID = "0000-0003-4198-9911")),
    person(given = "Brian",
           family = "Ripley", 
           role = "ctb", 
           email = "ripley@stats.ox.ac.uk",
           comment = "compilation fixes"),
    person(given = "Michael",
           family = "Koohafkan",
           role = "ctb", 
           email = "michael.koohafkan@gmail.com"), 
    person(given = c("Mathew", "W."), 
           family = "McLean",
           role = "ctb", 
           email = "mathew.w.mclean@gmail.com",
           comment = c(ORCID = "0000-0002-7891-9645")
           )
  )
Description: Utility to parse a bibtex file. 
BugReports: https://github.com/ropensci/bibtex/issues
URL: https://github.com/ropensci/bibtex,
        https://docs.ropensci.org/bibtex/
License: GPL (>= 2)
Depends: R (>= 3.0.2)
Imports: backports (>= 1.4.0), utils
Suggests: testthat (>= 3.0.0)
LazyLoad: yes
Encoding: UTF-8
RoxygenNote: 7.3.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-02-02 18:22:42 UTC; ronin
Author: Romain Francois [aut, cph] (ORCID:
    <https://orcid.org/0000-0002-2444-4226>, principal developer of
    bibtex R package),
  Diego Hernangómez [aut] (ORCID:
    <https://orcid.org/0000-0001-8457-4658>),
  James Joseph Balamuta [ctb, cre, aut] (ORCID:
    <https://orcid.org/0000-0003-2826-8458>),
  Scott Chamberlain [ctb] (ORCID:
    <https://orcid.org/0000-0003-1444-9135>),
  Kurt Hornik [ctb] (ORCID: <https://orcid.org/0000-0003-4198-9911>),
  Brian Ripley [ctb] (compilation fixes),
  Michael Koohafkan [ctb],
  Mathew W. McLean [ctb] (ORCID: <https://orcid.org/0000-0002-7891-9645>)
Maintainer: James Joseph Balamuta <balamut2@illinois.edu>
Repository: CRAN
Date/Publication: 2026-02-03 06:10:52 UTC
