# bibtex

<!-- badges: start -->
[![CRAN](https://www.r-pkg.org/badges/version/bibtex)](https://CRAN.R-project.org/package=bibtex) 
[![R-CMD-check](https://github.com/ropensci/bibtex/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/ropensci/bibtex/actions/workflows/R-CMD-check.yaml)
[![Coverage](https://codecov.io/github/ropensci/bibtex/coverage.svg?branch=master)](https://app.codecov.io/gh/ropensci/bibtex/branch/master) 
[![Downloads](https://cranlogs.r-pkg.org/badges/bibtex)](https://cran.r-project.org/package=bibtex)
[![Total Downloads](https://cranlogs.r-pkg.org/badges/grand-total/bibtex?color=blue)](https://cran.r-project.org/package=bibtex)
<!-- badges: end -->

## Installation

You can install bibtex from [CRAN](https://cran.r-project.org) with:

```r
install.packages("bibtex")
```

You can install bibtex from GitHub with:

```r
if(!requireNamespace("remotes", quietly = TRUE)) { install.packages("remotes") }
remotes::install_github("ropensci/bibtex")
```

### Acknowledgements

Without the work of [Romain François](https://github.com/romainfrancois), `bibtex`
likely wouldn't exist. Romain was the principal developer of `bibtex` up until 
2020 when he was unable to continue supporting the package due to time 
commitments. His work will continue on thanks in part to his willingness to 
donate it to rOpenSci.

### Meta

- Please [report any issues, bugs or feature requests](https://github.com/ropensci/bibtex/issues).
- License: GPL (>= 2)
- Get citation information for `bibtex` in R with `citation("bibtex")`
- Please note that this package is released with a [Contributor Code of Conduct](https://ropensci.org/code-of-conduct/). By contributing to this project, you agree to abide by its terms.

[![ropensci](https://ropensci.org//public_images/github_footer.png)](https://ropensci.org/)
