# Full xampl on string

    Code
      names(out)
    Output
       [1] "article-minimal"        "article-full"           "inbook-minimal"        
       [4] "inbook-full"            "inbook-crossref"        "book-minimal"          
       [7] "book-full"              "book-crossref"          "whole-set"             
      [10] "booklet-minimal"        "booklet-full"           "incollection-minimal"  
      [13] "incollection-full"      "incollection-crossref"  "whole-collection"      
      [16] "manual-minimal"         "manual-full"            "mastersthesis-minimal" 
      [19] "mastersthesis-full"     "misc-minimal"           "misc-full"             
      [22] "inproceedings-minimal"  "inproceedings-full"     "inproceedings-crossref"
      [25] "proceedings-minimal"    "proceedings-full"       "whole-proceedings"     
      [28] "phdthesis-minimal"      "phdthesis-full"         "techreport-minimal"    
      [31] "techreport-full"        "unpublished-minimal"    "unpublished-full"      
      [34] "random-note-crossref"  

---

    Aamport LA (1986). "The Gnats and Gnus Document Preparation System."
    _\mbox{G-Animal's} Journal_.
    
    Aamport LA (1986). "The Gnats and Gnus Document Preparation System."
    _\mbox{G-Animal's} Journal_, *41*(7), 73+. This is a full ARTICLE
    entry.
    
    Knuth DE (\noopsort{1973b}1973). "Fundamental Algorithms." In chapter
    1.2. Addison-Wesley.
    
    Knuth DE (\noopsort{1973b}1973). "Fundamental Algorithms." In volume 1
    series The Art of Computer Programming, chapter 1.2, Second edition,
    10-119. Addison-Wesley, Reading, Massachusetts. This is a full INBOOK
    entry.
    
    Knuth DE (\noopsort{1973b}1973). "Fundamental Algorithms." In volume 1
    series The Art of Computer Programming, chapter 1.2, Second edition.
    Addison-Wesley. This is a cross-referencing INBOOK entry.
    
    Knuth DE (\noopsort{1973c}1981). _Seminumerical Algorithms_.
    Addison-Wesley.
    
    Knuth DE (\noopsort{1973c}1981). _Seminumerical Algorithms_, volume 2
    series The Art of Computer Programming, Second edition. Addison-Wesley,
    Reading, Massachusetts. This is a full BOOK entry.
    
    Knuth DE (\noopsort{1973c}1981). _Seminumerical Algorithms_, volume 2
    series The Art of Computer Programming, Second edition. Addison-Wesley.
    This is a cross-referencing BOOK entry.
    
    Knuth DE (\noopsort{1973a}\switchargs{-90}{1968}). _The Art of Computer
    Programming_, series Four volumes. Addison-Wesley. Seven volumes
    planned (this is a cross-referenced set of BOOKs).
    
    bibtype Booklet not implemented
    
    bibtype Booklet not implemented
    
    Lincoll DD (1977). "Semigroups of Recurrences." In _High Speed Computer
    and Algorithm Organization_. Academic Press.
    
    Lincoll DD (1977). "Semigroups of Recurrences." In Lipcoll DJ, Lawrie
    DH, Sameh AH (eds.), _High Speed Computer and Algorithm Organization_,
    number 23 series Fast Computers, Third edition, 179-183. Academic
    Press, New York. This is a full INCOLLECTION entry.
    
    Lincoll DD (1977). "Semigroups of Recurrences." In Lipcoll DJ, Lawrie
    DH, Sameh AH (eds.), _High Speed Computer and Algorithm Organization_,
    number 23 series Fast Computers, Third edition, 179-183. Academic
    Press, New York. This is a cross-referencing INCOLLECTION entry.
    
    Lipcoll DJ, Lawrie DH, Sameh AH (eds.) (1977). _High Speed Computer and
    Algorithm Organization_, number 23 series Fast Computers, Third
    edition. Academic Press, New York. This is a cross-referenced BOOK
    (collection) entry.
    
    (????). _The Definitive Computer Manual_.
    
    Manmaker L (1986). _The Definitive Computer Manual_, Silver edition.
    Chips-R-Us, Silicon Valley. This is a full MANUAL entry.
    
    Masterly É (1988). _Mastering Thesis Writing_. Master's thesis,
    Stanford University.
    
    Masterly É (1988). _Mastering Thesis Writing_. Master's project,
    Stanford University, English Department. This is a full MASTERSTHESIS
    entry.
    
    (????). This is a minimal MISC entry.
    
    Missilany J (1984). "Handing out random pamphlets in airports." Handed
    out at O'Hare. This is a full MISC entry.
    
    Oaho AV, Ullman JD, Yannakakis M (1983). "On Notions of Information
    Transfer in VLSI Circuits." In _Proc. Fifteenth Annual ACM Symposium on
    the Theory of Computing_.
    
    Oaho AV, Ullman JD, Yannakakis M (1983). "On Notions of Information
    Transfer in VLSI Circuits." In Oz WV, Yannakakis M (eds.), _Proc.
    Fifteenth Annual ACM Symposium on the Theory of Computing_, number 17
    series All ACM Conferences, 133-139. The OX Association for Computing
    Machinery, Boston. This is a full INPROCEDINGS entry.
    
    Oaho AV, Ullman JD, Yannakakis M (1983). "On Notions of Information
    Transfer in VLSI Circuits." In _Proc. Fifteenth Annual ACM Symposium on
    the Theory of Computing_, 133-139. The OX Association for Computing
    Machinery, Boston. This is a cross-referencing INPROCEEDINGS entry.
    
    Anonymous (ed.) (1983). _Proc. Fifteenth Annual Symposium on the Theory
    of Computing_.
    
    Oz WV, Yannakakis M (eds.) (1983). _Proc. Fifteenth Annual Symposium on
    the Theory of Computing_, number 17 series All ACM Conferences. The OX
    Association for Computing Machinery, Boston. This is a full PROCEEDINGS
    entry.
    
    Anonymous (ed.) (1983). _Proc. Fifteenth Annual Symposium on the Theory
    of Computing_. The OX Association for Computing Machinery, Boston. This
    is a cross-referenced PROCEEDINGS.
    
    Phony-Baloney FP (1988). _Fighting Fire with Fire: Festooning French
    Phrases_. Ph.D. thesis, Fanstord University.
    
    Phony-Baloney FP (1988). _Fighting Fire with Fire: Festooning French
    Phrases_. PhD Dissertation, Fanstord University, Department of French.
    This is a full PHDTHESIS entry.
    
    Terrific T (1988). "An $O(n \logn / \! \log\logn)$ Sorting Algorithm."
    Fanstord University.
    
    Térrific T (1988). "An $O(n \logn / \! \log\logn)$ Sorting Algorithm."
    Wishful Research Result 7, Fanstord University, Computer Science
    Department, Fanstord, California. This is a full TECHREPORT entry.
    
    Ünderwood U, Ñet N, \=Pot P (????). "Lower Bounds for Wishful Research
    Results." Talk at Fanstord University (this is a minimal UNPUBLISHED
    entry).
    
    Ünderwood U, Ñet N, \=Pot P (1988). "Lower Bounds for Wishful Research
    Results." Talk at Fanstord University (this is a full UNPUBLISHED
    entry).
    
    (????). Volume~2 is listed under Knuth book-full.

# Full xampl on bibtex

    @Article{article-minimal,
      author = {L[eslie] A. Aamport},
      title = {The Gnats and Gnus Document Preparation System},
      journal = {\mbox{G-Animal's} Journal},
      year = {1986},
    }
    
    @Article{article-full,
      author = {L[eslie] A. Aamport},
      title = {The Gnats and Gnus Document Preparation System},
      journal = {\mbox{G-Animal's} Journal},
      year = {1986},
      volume = {41},
      number = {7},
      pages = {73+},
      month = {jul},
      note = {This is a full ARTICLE entry},
    }
    
    @InBook{inbook-minimal,
      author = {Donald E. Knuth},
      title = {Fundamental Algorithms},
      publisher = {Addison-Wesley},
      year = {{\noopsort{1973b}}1973},
      chapter = {1.2},
    }
    
    @InBook{inbook-full,
      author = {Donald E. Knuth},
      title = {Fundamental Algorithms},
      volume = {1},
      series = {The Art of Computer Programming},
      publisher = {Addison-Wesley},
      address = {Reading, Massachusetts},
      edition = {Second},
      month = {10~jan},
      year = {{\noopsort{1973b}}1973},
      type = {Section},
      chapter = {1.2},
      pages = {10--119},
      note = {This is a full INBOOK entry},
    }
    
    @InBook{inbook-crossref,
      crossref = {whole-set},
      title = {Fundamental Algorithms},
      volume = {1},
      series = {The Art of Computer Programming},
      edition = {Second},
      year = {{\noopsort{1973b}}1973},
      type = {Section},
      chapter = {1.2},
      note = {This is a cross-referencing INBOOK entry},
    }
    
    @Book{book-minimal,
      author = {Donald E. Knuth},
      title = {Seminumerical Algorithms},
      publisher = {Addison-Wesley},
      year = {{\noopsort{1973c}}1981},
    }
    
    @Book{book-full,
      author = {Donald E. Knuth},
      title = {Seminumerical Algorithms},
      volume = {2},
      series = {The Art of Computer Programming},
      publisher = {Addison-Wesley},
      address = {Reading, Massachusetts},
      edition = {Second},
      month = {10~jan},
      year = {{\noopsort{1973c}}1981},
      note = {This is a full BOOK entry},
    }
    
    @Book{book-crossref,
      crossref = {whole-set},
      title = {Seminumerical Algorithms},
      volume = {2},
      series = {The Art of Computer Programming},
      edition = {Second},
      year = {{\noopsort{1973c}}1981},
      note = {This is a cross-referencing BOOK entry},
    }
    
    @Book{whole-set,
      author = {Donald E. Knuth},
      publisher = {Addison-Wesley},
      title = {The Art of Computer Programming},
      series = {Four volumes},
      year = {{\noopsort{1973a}}{\switchargs{--90}{1968}}},
      note = {Seven volumes planned (this is a cross-referenced set of BOOKs)},
    }
    
    @Booklet{booklet-minimal,
      key = {Kn{\printfirst{v}{1987}}},
      title = {The Programming of Computer Art},
    }
    
    @Booklet{booklet-full,
      author = {Jill C. Knvth},
      title = {The Programming of Computer Art},
      howpublished = {Vernier Art Center},
      address = {Stanford, California},
      month = {feb},
      year = {1988},
      note = {This is a full BOOKLET entry},
    }
    
    @InCollection{incollection-minimal,
      author = {Daniel D. Lincoll},
      title = {Semigroups of Recurrences},
      booktitle = {High Speed Computer and Algorithm Organization},
      publisher = {Academic Press},
      year = {1977},
    }
    
    @InCollection{incollection-full,
      author = {Daniel D. Lincoll},
      title = {Semigroups of Recurrences},
      editor = {David J. Lipcoll and D. H. Lawrie and A. H. Sameh},
      booktitle = {High Speed Computer and Algorithm Organization},
      number = {23},
      series = {Fast Computers},
      chapter = {3},
      type = {Part},
      pages = {179--183},
      publisher = {Academic Press},
      address = {New York},
      edition = {Third},
      month = {sep},
      year = {1977},
      note = {This is a full INCOLLECTION entry},
    }
    
    @InCollection{incollection-crossref,
      crossref = {whole-collection},
      author = {Daniel D. Lincoll},
      title = {Semigroups of Recurrences},
      pages = {179--183},
      note = {This is a cross-referencing INCOLLECTION entry},
    }
    
    @Book{whole-collection,
      editor = {David J. Lipcoll and D. H. Lawrie and A. H. Sameh},
      title = {High Speed Computer and Algorithm Organization},
      booktitle = {High Speed Computer and Algorithm Organization},
      number = {23},
      series = {Fast Computers},
      publisher = {Academic Press},
      address = {New York},
      edition = {Third},
      month = {sep},
      year = {1977},
      note = {This is a cross-referenced BOOK (collection) entry},
    }
    
    @Manual{manual-minimal,
      key = {Manmaker},
      title = {The Definitive Computer Manual},
    }
    
    @Manual{manual-full,
      author = {Larry Manmaker},
      title = {The Definitive Computer Manual},
      organization = {Chips-R-Us},
      address = {Silicon Valley},
      edition = {Silver},
      month = {apr-may},
      year = {1986},
      note = {This is a full MANUAL entry},
    }
    
    @MastersThesis{mastersthesis-minimal,
      author = {Édouard Masterly},
      title = {Mastering Thesis Writing},
      school = {Stanford University},
      year = {1988},
    }
    
    @MastersThesis{mastersthesis-full,
      author = {Édouard Masterly},
      title = {Mastering Thesis Writing},
      school = {Stanford University},
      type = {Master's project},
      address = {English Department},
      month = {jun-aug},
      year = {1988},
      note = {This is a full MASTERSTHESIS entry},
    }
    
    @Misc{misc-minimal,
      key = {Missilany},
      note = {This is a minimal MISC entry},
    }
    
    @Misc{misc-full,
      author = {Joe-Bob Missilany},
      title = {Handing out random pamphlets in airports},
      howpublished = {Handed out at O'Hare},
      month = {oct},
      year = {1984},
      note = {This is a full MISC entry},
    }
    
    @InProceedings{inproceedings-minimal,
      author = {Alfred V. Oaho and Jeffrey D. Ullman and Mihalis Yannakakis},
      title = {On Notions of Information Transfer in {VLSI} Circuits},
      booktitle = {Proc. Fifteenth Annual ACM Symposium on the Theory of Computing},
      year = {1983},
    }
    
    @InProceedings{inproceedings-full,
      author = {Alfred V. Oaho and Jeffrey D. Ullman and Mihalis Yannakakis},
      title = {On Notions of Information Transfer in {VLSI} Circuits},
      editor = {Wizard V. Oz and Mihalis Yannakakis},
      booktitle = {Proc. Fifteenth Annual ACM Symposium on the Theory of Computing},
      number = {17},
      series = {All ACM Conferences},
      pages = {133--139},
      month = {mar},
      year = {1983},
      address = {Boston},
      organization = {The OX Association for Computing Machinery},
      publisher = {Academic Press},
      note = {This is a full INPROCEDINGS entry},
    }
    
    @InProceedings{inproceedings-crossref,
      crossref = {whole-proceedings},
      author = {Alfred V. Oaho and Jeffrey D. Ullman and Mihalis Yannakakis},
      title = {On Notions of Information Transfer in {VLSI} Circuits},
      pages = {133--139},
      note = {This is a cross-referencing INPROCEEDINGS entry},
    }
    
    @Proceedings{proceedings-minimal,
      key = {OX{\singleletter{stoc}}},
      title = {Proc. Fifteenth Annual Symposium on the Theory of Computing},
      year = {1983},
    }
    
    @Proceedings{proceedings-full,
      editor = {Wizard V. Oz and Mihalis Yannakakis},
      title = {Proc. Fifteenth Annual Symposium on the Theory of Computing},
      number = {17},
      series = {All ACM Conferences},
      month = {mar},
      year = {1983},
      address = {Boston},
      organization = {The OX Association for Computing Machinery},
      publisher = {Academic Press},
      note = {This is a full PROCEEDINGS entry},
    }
    
    @Proceedings{whole-proceedings,
      key = {OX{\singleletter{stoc}}},
      organization = {The OX Association for Computing Machinery},
      title = {Proc. Fifteenth Annual Symposium on the Theory of Computing},
      address = {Boston},
      year = {1983},
      booktitle = {Proc. Fifteenth Annual ACM Symposium on the Theory of Computing},
      note = {This is a cross-referenced PROCEEDINGS},
    }
    
    @PhdThesis{phdthesis-minimal,
      author = {F. Phidias Phony-Baloney},
      title = {Fighting Fire with Fire: Festooning {F}rench Phrases},
      school = {Fanstord University},
      year = {1988},
    }
    
    @PhdThesis{phdthesis-full,
      author = {F. Phidias Phony-Baloney},
      title = {Fighting Fire with Fire: Festooning {F}rench Phrases},
      school = {Fanstord University},
      type = {{PhD} Dissertation},
      address = {Department of French},
      month = {jun-aug},
      year = {1988},
      note = {This is a full PHDTHESIS entry},
    }
    
    @TechReport{techreport-minimal,
      author = {Tom Terrific},
      title = {An {$O(n \log n / \! \log\log n)$} Sorting Algorithm},
      institution = {Fanstord University},
      year = {1988},
    }
    
    @TechReport{techreport-full,
      author = {Tom Térrific},
      title = {An {$O(n \log n / \! \log\log n)$} Sorting Algorithm},
      institution = {Fanstord University},
      type = {Wishful Research Result},
      number = {7},
      address = {Computer Science Department, Fanstord, California},
      month = {oct},
      year = {1988},
      note = {This is a full TECHREPORT entry},
    }
    
    @Unpublished{unpublished-minimal,
      author = {Ulrich Ünderwood and Ned Ñet and Paul \=Pot},
      title = {Lower Bounds for Wishful Research Results},
      note = {Talk at Fanstord University (this is a minimal UNPUBLISHED entry)},
    }
    
    @Unpublished{unpublished-full,
      author = {Ulrich Ünderwood and Ned Ñet and Paul \=Pot},
      title = {Lower Bounds for Wishful Research Results},
      month = {nov, dec},
      year = {1988},
      note = {Talk at Fanstord University (this is a full UNPUBLISHED entry)},
    }
    
    @Misc{random-note-crossref,
      key = {Volume-2},
      note = {Volume~2 is listed under Knuth \cite{book-full}},
    }

