# Do read bib

                                              author 
                               "L[eslie] A. Aamport" 
                                               title 
    "The Gnats and Gnus Document Preparation System" 
                                             journal 
                        "\\mbox{G-Animal's} Journal" 
                                                year 
                                              "1986" 
                                              volume 
                                                "41" 
                                              number 
                                                 "7" 
                                               pages 
                                               "73+" 
                                               month 
                                               "jul" 
                                                note 
                      "This is a full ARTICLE entry" 
    attr(,"entry")
    [1] "ARTICLE"
    attr(,"key")
    [1] "article-full"

# Do read bib with non standard entries

                      author                    title                     date 
    "Van Damme, Jean-Claude"          "Article title"             "2016-12-21" 
                     journal 
            "Newspaper name" 
    attr(,"entry")
    [1] "Website"
    attr(,"key")
    [1] "newspaper"

# do read with several entries

                                              author 
                               "L[eslie] A. Aamport" 
                                               title 
    "The Gnats and Gnus Document Preparation System" 
                                             journal 
                        "\\mbox{G-Animal's} Journal" 
                                                year 
                                              "1986" 
                                              volume 
                                                "41" 
                                              number 
                                                 "7" 
                                               pages 
                                               "73+" 
                                               month 
                                               "jul" 
                                                note 
                      "This is a full ARTICLE entry" 
    attr(,"entry")
    [1] "ARTICLE"
    attr(,"key")
    [1] "article-full"
                               author                             title 
                    "Donald E. Knuth"        "Seminumerical Algorithms" 
                               volume                            series 
                                  "2" "The Art of Computer Programming" 
                            publisher                           address 
                     "Addison-Wesley"          "Reading, Massachusetts" 
                              edition                             month 
                             "Second"                          "10~jan" 
                                 year                              note 
            "{\\noopsort{1973c}}1981"       "This is a full BOOK entry" 
    attr(,"entry")
    [1] "BOOK"
    attr(,"key")
    [1] "book-full"
                               author                             title 
                      "Jill C. Knvth" "The Programming of Computer Art" 
                         howpublished                           address 
                 "Vernier Art Center"            "Stanford, California" 
                                month                              year 
                                "feb"                            "1988" 
                                 note 
       "This is a full BOOKLET entry" 
    attr(,"entry")
    [1] "BOOKLET"
    attr(,"key")
    [1] "booklet-full"
                               author                             title 
                    "Donald E. Knuth"          "Fundamental Algorithms" 
                               volume                            series 
                                  "1" "The Art of Computer Programming" 
                            publisher                           address 
                     "Addison-Wesley"          "Reading, Massachusetts" 
                              edition                             month 
                             "Second"                          "10~jan" 
                                 year                              type 
            "{\\noopsort{1973b}}1973"                         "Section" 
                              chapter                             pages 
                                "1.2"                         "10--119" 
                                 note 
        "This is a full INBOOK entry" 
    attr(,"entry")
    [1] "INBOOK"
    attr(,"key")
    [1] "inbook-full"
                                                 author 
                                    "Daniel D. Lincoll" 
                                                  title 
                            "Semigroups of Recurrences" 
                                                 editor 
    "David J. Lipcoll and D. H. Lawrie and A. H. Sameh" 
                                              booktitle 
       "High Speed Computer and Algorithm Organization" 
                                                 number 
                                                   "23" 
                                                 series 
                                       "Fast Computers" 
                                                chapter 
                                                    "3" 
                                                   type 
                                                 "Part" 
                                                  pages 
                                             "179--183" 
                                              publisher 
                                       "Academic Press" 
                                                address 
                                             "New York" 
                                                edition 
                                                "Third" 
                                                  month 
                                                  "sep" 
                                                   year 
                                                 "1977" 
                                                   note 
                    "This is a full INCOLLECTION entry" 
    attr(,"entry")
    [1] "INCOLLECTION"
    attr(,"key")
    [1] "incollection-full"
                                                           author 
    "Alfred V. Oaho and Jeffrey D. Ullman and Mihalis Yannakakis" 
                                                            title 
          "On Notions of Information Transfer in {VLSI} Circuits" 
                                                           editor 
                            "Wizard V. Oz and Mihalis Yannakakis" 
                                                        booktitle 
                                     "Proc. Fifteenth Annual ACM" 
                                                           number 
                                                             "17" 
                                                           series 
                                            "All ACM Conferences" 
                                                            pages 
                                                       "133--139" 
                                                            month 
                                                            "mar" 
                                                             year 
                                                           "1983" 
                                                          address 
                                                         "Boston" 
                                                     organization 
                                                            "ACM" 
                                                        publisher 
                                                 "Academic Press" 
                                                             note 
                              "This is a full INPROCEDINGS entry" 
    attr(,"entry")
    [1] "INPROCEEDINGS"
    attr(,"key")
    [1] "inproceedings-full"
                              author                            title 
                    "Larry Manmaker" "The Definitive Computer Manual" 
                        organization                          address 
                        "Chips-R-Us"                 "Silicon Valley" 
                             edition                            month 
                            "Silver"                        "apr-may" 
                                year                             note 
                              "1986"    "This is a full MANUAL entry" 
    attr(,"entry")
    [1] "MANUAL"
    attr(,"key")
    [1] "manual-full"
                                  author                                title 
               "{\\'{E}}douard Masterly"           "Mastering Thesis Writing" 
                                  school                                 type 
                   "Stanford University"                   "Master's project" 
                                 address                                month 
                    "English Department"                            "jun-aug" 
                                    year                                 note 
                                  "1988" "This is a full MASTERSTHESIS entry" 
    attr(,"entry")
    [1] "MASTERSTHESIS"
    attr(,"key")
    [1] "mastersthesis-full"
                                        author 
                           "Joe-Bob Missilany" 
                                         title 
    "Handing out random pamphlets in airports" 
                                  howpublished 
                        "Handed out at O'Hare" 
                                         month 
                                         "oct" 
                                          year 
                                        "1984" 
                                          note 
                   "This is a full MISC entry" 
    attr(,"entry")
    [1] "MISC"
    attr(,"key")
    [1] "misc-full"
                                                    author 
                                "F. Phidias Phony-Baloney" 
                                                     title 
    "Fighting Fire with Fire: Festooning {F}rench Phrases" 
                                                    school 
                                     "Fanstord University" 
                                                      type 
                                      "{PhD} Dissertation" 
                                                   address 
                                    "Department of French" 
                                                     month 
                                                 "jun-aug" 
                                                      year 
                                                    "1988" 
                                                      note 
                          "This is a full PHDTHESIS entry" 
    attr(,"entry")
    [1] "PHDTHESIS"
    attr(,"key")
    [1] "phdthesis-full"
                                   editor                                 title 
    "Wizard V. Oz and Mihalis Yannakakis"          "Proc. Fifteenth AnnualSTOC" 
                                   number                                series 
                                     "17"                 "All ACM Conferences" 
                                    month                                  year 
                                    "mar"                                "1983" 
                                  address                          organization 
                                 "Boston"                                 "ACM" 
                                publisher                                  note 
                         "Academic Press"    "This is a full PROCEEDINGS entry" 
    attr(,"entry")
    [1] "PROCEEDINGS"
    attr(,"key")
    [1] "proceedings-full"
                                                        author 
                                         "Tom T{\\'{e}}rrific" 
                                                         title 
    "An {$O(n \\log n / \\! \\log\\log n)$} Sorting Algorithm" 
                                                   institution 
                                         "Fanstord University" 
                                                          type 
                                     "Wishful Research Result" 
                                                        number 
                                                           "7" 
                                                       address 
           "Computer Science Department, Fanstord, California" 
                                                         month 
                                                         "oct" 
                                                          year 
                                                        "1988" 
                                                          note 
                             "This is a full TECHREPORT entry" 
    attr(,"entry")
    [1] "TECHREPORT"
    attr(,"key")
    [1] "techreport-full"
                                                              author 
     "Ulrich {\\\"{U}}nderwood and Ned {\\~N}et and Paul {\\={P}}ot" 
                                                               title 
                         "Lower Bounds for Wishful Research Results" 
                                                               month 
                                                          "nov, dec" 
                                                                year 
                                                              "1988" 
                                                                note 
    "Talk at Fanstord University (this is a full UNPUBLISHED entry)" 
    attr(,"entry")
    [1] "UNPUBLISHED"
    attr(,"key")
    [1] "unpublished-full"
    [[1]]
                                              author 
                               "L[eslie] A. Aamport" 
                                               title 
    "The Gnats and Gnus Document Preparation System" 
                                             journal 
                        "\\mbox{G-Animal's} Journal" 
                                                year 
                                              "1986" 
                                              volume 
                                                "41" 
                                              number 
                                                 "7" 
                                               pages 
                                               "73+" 
                                               month 
                                               "jul" 
                                                note 
                      "This is a full ARTICLE entry" 
    attr(,"entry")
    [1] "ARTICLE"
    attr(,"key")
    [1] "article-full"
    
    [[2]]
                               author                             title 
                    "Donald E. Knuth"        "Seminumerical Algorithms" 
                               volume                            series 
                                  "2" "The Art of Computer Programming" 
                            publisher                           address 
                     "Addison-Wesley"          "Reading, Massachusetts" 
                              edition                             month 
                             "Second"                          "10~jan" 
                                 year                              note 
            "{\\noopsort{1973c}}1981"       "This is a full BOOK entry" 
    attr(,"entry")
    [1] "BOOK"
    attr(,"key")
    [1] "book-full"
    
    [[3]]
                               author                             title 
                      "Jill C. Knvth" "The Programming of Computer Art" 
                         howpublished                           address 
                 "Vernier Art Center"            "Stanford, California" 
                                month                              year 
                                "feb"                            "1988" 
                                 note 
       "This is a full BOOKLET entry" 
    attr(,"entry")
    [1] "BOOKLET"
    attr(,"key")
    [1] "booklet-full"
    
    [[4]]
                               author                             title 
                    "Donald E. Knuth"          "Fundamental Algorithms" 
                               volume                            series 
                                  "1" "The Art of Computer Programming" 
                            publisher                           address 
                     "Addison-Wesley"          "Reading, Massachusetts" 
                              edition                             month 
                             "Second"                          "10~jan" 
                                 year                              type 
            "{\\noopsort{1973b}}1973"                         "Section" 
                              chapter                             pages 
                                "1.2"                         "10--119" 
                                 note 
        "This is a full INBOOK entry" 
    attr(,"entry")
    [1] "INBOOK"
    attr(,"key")
    [1] "inbook-full"
    
    [[5]]
                                                 author 
                                    "Daniel D. Lincoll" 
                                                  title 
                            "Semigroups of Recurrences" 
                                                 editor 
    "David J. Lipcoll and D. H. Lawrie and A. H. Sameh" 
                                              booktitle 
       "High Speed Computer and Algorithm Organization" 
                                                 number 
                                                   "23" 
                                                 series 
                                       "Fast Computers" 
                                                chapter 
                                                    "3" 
                                                   type 
                                                 "Part" 
                                                  pages 
                                             "179--183" 
                                              publisher 
                                       "Academic Press" 
                                                address 
                                             "New York" 
                                                edition 
                                                "Third" 
                                                  month 
                                                  "sep" 
                                                   year 
                                                 "1977" 
                                                   note 
                    "This is a full INCOLLECTION entry" 
    attr(,"entry")
    [1] "INCOLLECTION"
    attr(,"key")
    [1] "incollection-full"
    
    [[6]]
                                                           author 
    "Alfred V. Oaho and Jeffrey D. Ullman and Mihalis Yannakakis" 
                                                            title 
          "On Notions of Information Transfer in {VLSI} Circuits" 
                                                           editor 
                            "Wizard V. Oz and Mihalis Yannakakis" 
                                                        booktitle 
                                     "Proc. Fifteenth Annual ACM" 
                                                           number 
                                                             "17" 
                                                           series 
                                            "All ACM Conferences" 
                                                            pages 
                                                       "133--139" 
                                                            month 
                                                            "mar" 
                                                             year 
                                                           "1983" 
                                                          address 
                                                         "Boston" 
                                                     organization 
                                                            "ACM" 
                                                        publisher 
                                                 "Academic Press" 
                                                             note 
                              "This is a full INPROCEDINGS entry" 
    attr(,"entry")
    [1] "INPROCEEDINGS"
    attr(,"key")
    [1] "inproceedings-full"
    
    [[7]]
                              author                            title 
                    "Larry Manmaker" "The Definitive Computer Manual" 
                        organization                          address 
                        "Chips-R-Us"                 "Silicon Valley" 
                             edition                            month 
                            "Silver"                        "apr-may" 
                                year                             note 
                              "1986"    "This is a full MANUAL entry" 
    attr(,"entry")
    [1] "MANUAL"
    attr(,"key")
    [1] "manual-full"
    
    [[8]]
                                  author                                title 
               "{\\'{E}}douard Masterly"           "Mastering Thesis Writing" 
                                  school                                 type 
                   "Stanford University"                   "Master's project" 
                                 address                                month 
                    "English Department"                            "jun-aug" 
                                    year                                 note 
                                  "1988" "This is a full MASTERSTHESIS entry" 
    attr(,"entry")
    [1] "MASTERSTHESIS"
    attr(,"key")
    [1] "mastersthesis-full"
    
    [[9]]
                                        author 
                           "Joe-Bob Missilany" 
                                         title 
    "Handing out random pamphlets in airports" 
                                  howpublished 
                        "Handed out at O'Hare" 
                                         month 
                                         "oct" 
                                          year 
                                        "1984" 
                                          note 
                   "This is a full MISC entry" 
    attr(,"entry")
    [1] "MISC"
    attr(,"key")
    [1] "misc-full"
    
    [[10]]
                                                    author 
                                "F. Phidias Phony-Baloney" 
                                                     title 
    "Fighting Fire with Fire: Festooning {F}rench Phrases" 
                                                    school 
                                     "Fanstord University" 
                                                      type 
                                      "{PhD} Dissertation" 
                                                   address 
                                    "Department of French" 
                                                     month 
                                                 "jun-aug" 
                                                      year 
                                                    "1988" 
                                                      note 
                          "This is a full PHDTHESIS entry" 
    attr(,"entry")
    [1] "PHDTHESIS"
    attr(,"key")
    [1] "phdthesis-full"
    
    [[11]]
                                   editor                                 title 
    "Wizard V. Oz and Mihalis Yannakakis"          "Proc. Fifteenth AnnualSTOC" 
                                   number                                series 
                                     "17"                 "All ACM Conferences" 
                                    month                                  year 
                                    "mar"                                "1983" 
                                  address                          organization 
                                 "Boston"                                 "ACM" 
                                publisher                                  note 
                         "Academic Press"    "This is a full PROCEEDINGS entry" 
    attr(,"entry")
    [1] "PROCEEDINGS"
    attr(,"key")
    [1] "proceedings-full"
    
    [[12]]
                                                        author 
                                         "Tom T{\\'{e}}rrific" 
                                                         title 
    "An {$O(n \\log n / \\! \\log\\log n)$} Sorting Algorithm" 
                                                   institution 
                                         "Fanstord University" 
                                                          type 
                                     "Wishful Research Result" 
                                                        number 
                                                           "7" 
                                                       address 
           "Computer Science Department, Fanstord, California" 
                                                         month 
                                                         "oct" 
                                                          year 
                                                        "1988" 
                                                          note 
                             "This is a full TECHREPORT entry" 
    attr(,"entry")
    [1] "TECHREPORT"
    attr(,"key")
    [1] "techreport-full"
    
    [[13]]
                                                              author 
     "Ulrich {\\\"{U}}nderwood and Ned {\\~N}et and Paul {\\={P}}ot" 
                                                               title 
                         "Lower Bounds for Wishful Research Results" 
                                                               month 
                                                          "nov, dec" 
                                                                year 
                                                              "1988" 
                                                                note 
    "Talk at Fanstord University (this is a full UNPUBLISHED entry)" 
    attr(,"entry")
    [1] "UNPUBLISHED"
    attr(,"key")
    [1] "unpublished-full"
    

