# Full xampl on string

    Aamport LA (1986). "The Gnats and Gnus Document Preparation System."
    _\mbox{G-Animal's} Journal_.
    
    Aamport LA (1986). "The Gnats and Gnus Document Preparation System."
    _\mbox{G-Animal's} Journal_, *41*(7), 73+. This is a full ARTICLE
    entry.
    
    Knuth DE (\noopsort{1973b}1973). "Fundamental Algorithms." In chapter
    1.2. Addison-Wesley.
    
    Knuth DE (\noopsort{1973b}1973). "Fundamental Algorithms." In volume 1
    series The Art of Computer Programming, chapter 1.2, 10-119, Second
    edition. Addison-Wesley, Reading, Massachusetts. This is a full INBOOK
    entry.
    
    Knuth DE (\noopsort{1973b}1973). "Fundamental Algorithms." In volume 1
    series The Art of Computer Programming, chapter 1.2, Second edition.
    Addison-Wesley. This is a cross-referencing INBOOK entry.
    
    Knuth DE (\noopsort{1973c}1981). _Seminumerical Algorithms_.
    Addison-Wesley.
    
    Knuth DE (\noopsort{1973c}1981). _Seminumerical Algorithms_, volume 2
    series The Art of Computer Programming, Second edition. Addison-Wesley,
    Reading, Massachusetts. This is a full BOOK entry.
    
    Knuth DE (\noopsort{1973c}1981). _Seminumerical Algorithms_, volume 2
    series The Art of Computer Programming, Second edition. Addison-Wesley.
    This is a cross-referencing BOOK entry.
    
    Knuth DE (\noopsort{1973a}\switchargs{-90}{1968}). _The Art of Computer
    Programming_, series Four volumes. Addison-Wesley. Seven volumes
    planned (this is a cross-referenced set of BOOKs).
    
    bibtype Booklet not implemented
    
    bibtype Booklet not implemented
    
    Lincoll DD (1977). "Semigroups of Recurrences." In _High Speed Computer
    and Algorithm Organization_. Academic Press.
    
    Lincoll DD (1977). "Semigroups of Recurrences." In Lipcoll DJ, Lawrie
    DH, Sameh AH (eds.), _High Speed Computer and Algorithm Organization_,
    number 23 series Fast Computers, Third edition, chapter 3, 179-183.
    Academic Press, New York. This is a full INCOLLECTION entry.
    
    Lincoll DD (1977). "Semigroups of Recurrences." In Lipcoll DJ, Lawrie
    DH, Sameh AH (eds.), _High Speed Computer and Algorithm Organization_,
    number 23 series Fast Computers, Third edition, 179-183. Academic
    Press, New York. This is a cross-referencing INCOLLECTION entry.
    
    Lipcoll DJ, Lawrie DH, Sameh AH (eds.) (1977). _High Speed Computer and
    Algorithm Organization_, number 23 series Fast Computers, Third
    edition. Academic Press, New York. This is a cross-referenced BOOK
    (collection) entry.
    
    (????). _The Definitive Computer Manual_.
    
    Manmaker L (1986). _The Definitive Computer Manual_, Silver edition.
    Chips-R-Us, Silicon Valley. This is a full MANUAL entry.
    
    Masterly É (1988). _Mastering Thesis Writing_. Master's thesis,
    Stanford University.
    
    Masterly É (1988). _Mastering Thesis Writing_. Master's project,
    Stanford University, English Department. This is a full MASTERSTHESIS
    entry.
    
    (????). This is a minimal MISC entry.
    
    Missilany J (1984). "Handing out random pamphlets in airports." Handed
    out at O'Hare. This is a full MISC entry.
    
    Oaho AV, Ullman JD, Yannakakis M (1983). "On Notions of Information
    Transfer in VLSI Circuits." In _Proc. Fifteenth Annual ACM Symposium on
    the Theory of Computing_.
    
    Oaho AV, Ullman JD, Yannakakis M (1983). "On Notions of Information
    Transfer in VLSI Circuits." In Oz WV, Yannakakis M (eds.), _Proc.
    Fifteenth Annual ACM Symposium on the Theory of Computing_, number 17
    series All ACM Conferences, 133-139. The OX Association for Computing
    Machinery, Boston. This is a full INPROCEDINGS entry.
    
    Oaho AV, Ullman JD, Yannakakis M (1983). "On Notions of Information
    Transfer in VLSI Circuits." In _Proc. Fifteenth Annual ACM Symposium on
    the Theory of Computing_, 133-139. The OX Association for Computing
    Machinery, Boston. This is a cross-referencing INPROCEEDINGS entry.
    
    Anonymous (ed.) (1983). _Proc. Fifteenth Annual Symposium on the Theory
    of Computing_.
    
    Oz WV, Yannakakis M (eds.) (1983). _Proc. Fifteenth Annual Symposium on
    the Theory of Computing_, number 17 series All ACM Conferences. The OX
    Association for Computing Machinery, Boston. This is a full PROCEEDINGS
    entry.
    
    Anonymous (ed.) (1983). _Proc. Fifteenth Annual Symposium on the Theory
    of Computing_. The OX Association for Computing Machinery, Boston. This
    is a cross-referenced PROCEEDINGS.
    
    Phony-Baloney FP (1988). _Fighting Fire with Fire: Festooning French
    Phrases_. Ph.D. thesis, Fanstord University.
    
    Phony-Baloney FP (1988). _Fighting Fire with Fire: Festooning French
    Phrases_. PhD Dissertation, Fanstord University, Department of French.
    This is a full PHDTHESIS entry.
    
    Terrific T (1988). "An O(n \log n / \! \log\log n) Sorting Algorithm."
    Fanstord University.
    
    Térrific T (1988). "An O(n \log n / \! \log\log n) Sorting Algorithm."
    Wishful Research Result 7, Fanstord University, Computer Science
    Department, Fanstord, California. This is a full TECHREPORT entry.
    
    Ünderwood U, Ñet N, \= Pot P (????). "Lower Bounds for Wishful Research
    Results." Talk at Fanstord University (this is a minimal UNPUBLISHED
    entry).
    
    Ünderwood U, Ñet N, \= Pot P (1988). "Lower Bounds for Wishful Research
    Results." Talk at Fanstord University (this is a full UNPUBLISHED
    entry).
    
    (????). Volume~2 is listed under Knuth 'book-full'.

