# Test article-full

    @Article{article-full,
      author = {L[eslie] A. Aamport},
      title = {The Gnats and Gnus Document Preparation System},
      journal = {\mbox{G-Animal's} Journal},
      year = {1986},
      volume = {41},
      number = {7},
      pages = {73+},
      month = {jul},
      note = {This is a full ARTICLE entry},
    }

# Test book-full

    @Book{book-full,
      author = {Donald E. Knuth},
      title = {Seminumerical Algorithms},
      volume = {2},
      series = {The Art of Computer Programming},
      publisher = {Addison-Wesley},
      address = {Reading, Massachusetts},
      edition = {Second},
      month = {10~jan},
      year = {{\noopsort{1973c}}1981},
      note = {This is a full BOOK entry},
    }

# Test booklet-full

    @Booklet{booklet-full,
      author = {Jill C. Knvth},
      title = {The Programming of Computer Art},
      howpublished = {Vernier Art Center},
      address = {Stanford, California},
      month = {feb},
      year = {1988},
      note = {This is a full BOOKLET entry},
    }

# Test inbook-full

    @InBook{inbook-full,
      author = {Donald E. Knuth},
      title = {Fundamental Algorithms},
      volume = {1},
      series = {The Art of Computer Programming},
      publisher = {Addison-Wesley},
      address = {Reading, Massachusetts},
      edition = {Second},
      month = {10~jan},
      year = {{\noopsort{1973b}}1973},
      type = {Section},
      chapter = {1.2},
      pages = {10--119},
      note = {This is a full INBOOK entry},
    }

# Test incollection-full

    @InCollection{incollection-full,
      author = {Daniel D. Lincoll},
      title = {Semigroups of Recurrences},
      editor = {David J. Lipcoll and D. H. Lawrie and A. H. Sameh},
      booktitle = {High Speed Computer and Algorithm Organization},
      number = {23},
      series = {Fast Computers},
      chapter = {3},
      type = {Part},
      pages = {179--183},
      publisher = {Academic Press},
      address = {New York},
      edition = {Third},
      month = {sep},
      year = {1977},
      note = {This is a full INCOLLECTION entry},
    }

# Test inproceedings-full

    @InProceedings{inproceedings-full,
      author = {Alfred V. Oaho and Jeffrey D. Ullman and Mihalis Yannakakis},
      title = {On Notions of Information Transfer in {VLSI} Circuits},
      editor = {Wizard V. Oz and Mihalis Yannakakis},
      booktitle = {Proc. Fifteenth Annual ACM},
      number = {17},
      series = {All ACM Conferences},
      pages = {133--139},
      month = {mar},
      year = {1983},
      address = {Boston},
      organization = {ACM},
      publisher = {Academic Press},
      note = {This is a full INPROCEDINGS entry},
    }

# Test manual-full

    @Manual{manual-full,
      author = {Larry Manmaker},
      title = {The Definitive Computer Manual},
      organization = {Chips-R-Us},
      address = {Silicon Valley},
      edition = {Silver},
      month = {apr-may},
      year = {1986},
      note = {This is a full MANUAL entry},
    }

# Test mastersthesis-full

    @MastersThesis{mastersthesis-full,
      author = {Édouard Masterly},
      title = {Mastering Thesis Writing},
      school = {Stanford University},
      type = {Master's project},
      address = {English Department},
      month = {jun-aug},
      year = {1988},
      note = {This is a full MASTERSTHESIS entry},
    }

# Test misc-full

    @Misc{misc-full,
      author = {Joe-Bob Missilany},
      title = {Handing out random pamphlets in airports},
      howpublished = {Handed out at O'Hare},
      month = {oct},
      year = {1984},
      note = {This is a full MISC entry},
    }

# Test phdthesis-full

    @PhdThesis{phdthesis-full,
      author = {F. Phidias Phony-Baloney},
      title = {Fighting Fire with Fire: Festooning {F}rench Phrases},
      school = {Fanstord University},
      type = {{PhD} Dissertation},
      address = {Department of French},
      month = {jun-aug},
      year = {1988},
      note = {This is a full PHDTHESIS entry},
    }

# Test proceedings-full

    @Proceedings{proceedings-full,
      editor = {Wizard V. Oz and Mihalis Yannakakis},
      title = {Proc. Fifteenth AnnualSTOC},
      number = {17},
      series = {All ACM Conferences},
      month = {mar},
      year = {1983},
      address = {Boston},
      organization = {ACM},
      publisher = {Academic Press},
      note = {This is a full PROCEEDINGS entry},
    }

# Test techreport-full

    @TechReport{techreport-full,
      author = {Tom Térrific},
      title = {An {$O(n \log n / \! \log\log n)$} Sorting Algorithm},
      institution = {Fanstord University},
      type = {Wishful Research Result},
      number = {7},
      address = {Computer Science Department, Fanstord, California},
      month = {oct},
      year = {1988},
      note = {This is a full TECHREPORT entry},
    }

# Test unpublished-full

    @Unpublished{unpublished-full,
      author = {Ulrich Ünderwood and Ned Ñet and Paul \=Pot},
      title = {Lower Bounds for Wishful Research Results},
      month = {nov, dec},
      year = {1988},
      note = {Talk at Fanstord University (this is a full UNPUBLISHED entry)},
    }

