# Read base

    Chambers JM (1998). _Programming with Data_. Springer, New York. ISBN
    0-387-98503-4, <http://cm.bell-labs.com/cm/ms/departments/sia/Sbook/>.
    
    Becker RA, Chambers JM, Wilks AR (1988). _The New S Language_. Chapman
    & Hall, London.
    
    Chambers JM, Hastie TJ (1992). _Statistical Models in S_. Chapman &
    Hall, London. ISBN 9780412830402.
    
    Dongarra JJ, Bunch JR, Moder CB, Stewart GW (1978). _LINPACK users
    guide_. SIAM, Philadelphia.
    
    Abramowitz M, Stegun IA (1972). _Handbook of Mathematical Functions_.
    Dover Publications, New York.
    
    E. A, ten others (1999). _LAPACK Users Guide_, Third edition.
    <http://www.netlib.org/lapack/lug/lapack_lug.html>.
    
    Smith BT, Boyle JM, Dongarra JJ, Garbow BS, Ikebe Y, Klema V, Moler CB
    (1976). _Matrix Eigensystems Routines - EISPACK Guide_.
    Springer-Verlag.
    
    Lang DT (2001). _An Extensible Conversion Mechanism for .C() calls_.
    <http://developer.R-project.org/CObjectConversion.pdf>.
    
    Wilkinson JH (1965). _The Algebraic Eigenvalue Problem_. Clarendon
    Press, Oxford.
    
    Kernighan BW, Ritchie DM (1988). _The C Programming Language_, Second
    Edition edition. Prentice Hall.
    
    for Standardization IO (2004, 1988, 1997, ...). _ISO 8601. Data
    elements and interchange formats - Information interchange -
    Representation of dates and times_.
    <http://www.qsl.net/g1smd/isopdf.htm>.
    
    R Development Core Team (2009). _Writing R extensions_. R Foundation
    for Statistical Computing, Vienna, Austria.
    <http://cran.r-project.org/doc/manuals/R-exts.html>.
    
    R Development Core Team (2009). _R installation and Administration_. R
    Foundation for Statistical Computing, Vienna, Austria.
    <http://cran.r-project.org/doc/manuals/R-admin.html>.
    
    Lang DT (2001). "In Search of C/C++ & FORTRAN Routines." _R News_,
    *1*(3), 20-23. <http://CRAN.R-project.org/doc/Rnews/>.
    
    Goldberg D (1991). "What Every Computer Scientist Should Know about
    Floating-Point Arithmetic." _ACM Computing Surveys_, *23*(1).
    <http://www.validlab.com/goldberg/>.
    
    Chambers JM, Cleveland WS, Kleiner B, Tukey P (1983). _Graphical
    Methods for Data Analysis_. Wadsworth.
    
    Searle SR (1982). _Matrix Algebra Useful for Statistics_. John Wiley
    and Sons.
    
    Venables WN, Ripley BD (2002). _Modern Applied Statistics with S.
    Fourth Edition_. Springer, New York. ISBN 0-387-95457-0,
    <http://www.stats.ox.ac.uk/pub/MASS4/>.
    
    Jenkins, Traub (1972). "TOMS Algorithm 419." _Comm. ACM_, 97-99.
    
    Ripley BD (1987). _Stochastic Simulation_. Wiley.
    
    Loukides Mea (2002). _Unix Power Tools_. O Reilly.
    
    Sedgewick R (1986). "A new upper bound for Shell sort." _J.
    Algorithms_, 159-173.
    
    Singleton RC (1969). "An efficient algorithm for sorting with minimal
    storage: Algorithm 347." _Communications of the ACM_, 185-187.
    
    Cody WJ (1988). "MACHAR: A subroutine to dynamically determine machine
    parameters." _Transactions on Mathematical Software_, 303-311.
    
    Kuhn M (????). "ASCII and Unicode quotation marks."
    <http://www.cl.cam.ac.uk/~mgk25/ucs/quotes.html>.
    
    Huffman M (2003). "Operating Systems, Unix Shell (bash) / Windows
    Console (CMD.EXE)." <http://www.mhuffman.com/notes/dos/bash_cmd.htm>.
    
    (2009). "Collating Sequence."
    <http://en.wikipedia.org/wiki/Collating_sequence>.
    
    Davis M, Whistler K (2008). "Unicode Collation Algorithm."
    <http://unicode.org/reports/tr10/>.
    
    Ahrens JH, Dieter U (1973). "Extensions of Forsythes method for random
    sampling from the normal distribution." _Mathematics of Computation_,
    927-937.
    
    Box GEP, Muller ME (1958). "A note on the generation of normal random
    deviates." _Annals of Mathematical Statistics_, 610-611.
    
    De Matteis A, Pagnutti S (1993). "Long-range Correlation Analysis of
    the Wichmann-Hill Random Number Generator." _Statist. Comput._, 67-70.
    
    Kinderman AJ, Ramage JG (1976). "Computer generation of normal random
    variables." _Journal of the American Statistical Association_, 893-896.
    
    Knuth DE (1997). _The Art of Computer Programming_, volume 2, Third
    edition edition. Addison-Wesley Professional.
    <http://www-cs-faculty.stanford.edu/~knuth/taocp.html>.
    
    Knuth DE (1997). _The Art of Computer Programming_, volume 2, Third
    edition, ninth printing edition. Addison-Wesley Professional.
    <http://Sunburn.Stanford.EDU/~knuth/news02.html>.
    
    Marsaglia G (1997). "A random number generator for C." Discussion
    paper, posting on sci.stat.math usenet group.
    
    Marsaglia G, Zaman A (1994). "Some portable very-long-period random
    number generators." _Computers in Physics_, 117-121.
    
    Matsumoto M, Nishimura T (1998). "Mersenne Twister: A 623-dimensionally
    equidistributed uniform pseudo-random number generator." _ACM
    Transactions on Modeling and Computer Simulation_, 3-30.
    <http://www.math.keio.ac.jp/~matumoto/emt.html>.
    
    Reeds J, Hubert S, Abrahams M (1982-4). "C implementation of
    SuperDuper, University of California at Berkeley." Personal
    communication from Jim Reeds to Ross Ihaka.
    
    Wichmann BA, Hill ID (1982). "Algorithm AS 183: An Efficient and
    Portable Pseudo-random Number Generator." _Applied Statistics_,
    188-190. Remarks: 34, 198 and 35, 89.
    
    (????). "ANSI/IEEE 754 Floating-Point Standard."
    <http://grouper.ieee.org/groups/754/>.

---

    @Book{R:Chambers:1998,
      author = {John M. Chambers},
      title = {Programming with Data},
      publisher = {Springer},
      year = {1998},
      address = {New York},
      note = {ISBN 0-387-98503-4},
      url = {http://cm.bell-labs.com/cm/ms/departments/sia/Sbook/},
      publisherurl = {http://www.springeronline.com/sgw/cda/frontpage/0,11855,4-40109-22-2008951-0,00.html},
      abstract = {This Green Book describes version 4 of S, a
                      major revision of S designed by John Chambers to
                      improve its usefulness at every stage of the
                      programming process.},
    }
    
    @Book{R:Becker+Chambers+Wilks:1988,
      author = {Richard A. Becker and John M. Chambers and Allan R. Wilks},
      title = {The New {S} Language},
      publisher = {Chapman \& Hall},
      year = {1988},
      address = {London},
      abstract = {This book is often called the {Blue Book},
                      and introduced what is now known as S version 3, or S3.},
    }
    
    @Book{R:Chambers+Hastie:1992,
      author = {John M. Chambers and Trevor J. Hastie},
      title = {Statistical Models in {S}},
      publisher = {Chapman \& Hall},
      year = {1992},
      address = {London},
      note = {ISBN 9780412830402},
      publisherurl = {http://www.crcpress.com/shopping_cart/products/product_detail.asp?sku=C3040&parent_id=&pc=},
      abstract = {This is also called the {White Book}.
                      It described software for statistical modeling in S
                      and introduced the S3 version of classes and methods.},
    }
    
    @Book{linpack,
      author = {J. J. Dongarra and J. R. Bunch and C. B. Moder and G. W. Stewart},
      title = {LINPACK users guide},
      publisher = {SIAM},
      address = {Philadelphia},
      year = {1978},
    }
    
    @Book{handbook+math+functions,
      author = {M. Abramowitz and I. A Stegun},
      year = {1972},
      title = {Handbook of Mathematical Functions},
      address = {New York},
      publisher = {Dover Publications},
    }
    
    @Manual{lapack,
      author = {Anderson. E. and {ten others}},
      year = {1999},
      title = {{LAPACK} Users Guide},
      url = {http://www.netlib.org/lapack/lug/lapack_lug.html},
      publisher = {SIAM},
      edition = {Third},
    }
    
    @Book{eigen,
      author = {B. T Smith and J. M. Boyle and J. J. Dongarra and B. S. Garbow and Y. Ikebe and V. Klema and C. B. Moler},
      year = {1976},
      publisher = {Springer-Verlag},
      title = {Matrix Eigensystems Routines -- {EISPACK} Guide},
    }
    
    @Manual{cobjectconversion,
      author = {Duncan Temple Lang},
      year = {2001},
      url = {http://developer.R-project.org/CObjectConversion.pdf},
      title = {An Extensible Conversion Mechanism for {.C()} calls},
    }
    
    @Book{algebraicEigen,
      author = {J. H. Wilkinson},
      year = {1965},
      publisher = {Clarendon Press},
      address = {Oxford},
      title = {The Algebraic Eigenvalue Problem},
    }
    
    @Book{C,
      author = {B. W. Kernighan and D. M. Ritchie},
      year = {1988},
      title = {The C Programming Language},
      edition = {Second Edition},
      publisher = {Prentice Hall},
    }
    
    @Manual{dateformats,
      author = {International Organization {for Standardization}},
      title = {ISO 8601. Data elements and interchange formats -- Information interchange -- Representation of dates and times},
      year = {2004, 1988, 1997, ...},
      url = {http://www.qsl.net/g1smd/isopdf.htm},
    }
    
    @Manual{R:writingRExtensions,
      author = {{R Development Core Team}},
      organization = {R Foundation for Statistical Computing},
      address = {Vienna, Austria},
      year = {2009},
      title = {Writing R extensions},
      url = {http://cran.r-project.org/doc/manuals/R-exts.html},
    }
    
    @Manual{R:installadmin,
      author = {{R Development Core Team}},
      organization = {R Foundation for Statistical Computing},
      address = {Vienna, Austria},
      year = {2009},
      title = {R installation and Administration},
      url = {http://cran.r-project.org/doc/manuals/R-admin.html},
    }
    
    @Article{Rnews:Lang:2001a,
      author = {Duncan Temple Lang},
      title = {In Search of {C/C++} \& {FORTRAN} Routines},
      journal = {R News},
      year = {2001},
      volume = {1},
      number = {3},
      pages = {20--23},
      month = {September},
      url = {http://CRAN.R-project.org/doc/Rnews/},
      pdf = {http://CRAN.R-project.org/doc/Rnews/Rnews_2001-3.pdf},
    }
    
    @Article{floatingpoint,
      author = {D. Goldberg},
      year = {1991},
      title = {What Every Computer Scientist Should Know about Floating-Point Arithmetic},
      journal = {ACM Computing Surveys},
      volume = {23},
      number = {1},
      url = {http://www.validlab.com/goldberg/},
      pdf = {http://www.validlab.com/goldberg/paper.pdf},
    }
    
    @Book{graphicalmethods,
      author = {J. M. Chambers and W. S. Cleveland and B. Kleiner and P.A. Tukey},
      title = {Graphical Methods for Data Analysis},
      publisher = {Wadsworth},
      year = {1983},
    }
    
    @Book{matrixAlgebra,
      author = {Shayle R. Searle},
      title = {Matrix Algebra Useful for Statistics},
      publisher = {John Wiley and Sons},
      year = {1982},
    }
    
    @Book{MASS,
      author = {William N. Venables and Brian D. Ripley},
      title = {Modern Applied Statistics with {S}. Fourth Edition},
      publisher = {Springer},
      year = {2002},
      address = {New York},
      note = {ISBN 0-387-95457-0},
      url = {http://www.stats.ox.ac.uk/pub/MASS4/},
      publisherurl = {http://www.springeronline.com/sgw/cda/frontpage/0,11855,4-40109-22-1542120-0,00.html},
      abstract = {A highly recommended book on how to do statistical
                      data analysis using R or S-Plus.  In the first
                      chapters it gives an introduction to the S language.
                      Then it covers a wide range of statistical
                      methodology, including linear and generalized linear
                      models, non-linear and smooth regression, tree-based
                      methods, random and mixed effects, exploratory
                      multivariate analysis, classification, survival
                      analysis, time series analysis, spatial statistics,
                      and optimization.  The on-line complements available
                      at the books homepage provide updates of the book, as
                      well as further details of technical material.},
      orderinfo = {http://www.r-project.org/doc/bib/springer.txt},
    }
    
    @Article{toms+algorithm,
      author = {{Jenkins} and {Traub}},
      year = {1972},
      title = {{TOMS} Algorithm 419},
      journal = {Comm. ACM},
      edition = {15},
      pages = {97--99},
    }
    
    @Book{StockasticSimulation,
      author = {B. D. Ripley},
      title = {Stochastic Simulation},
      publisher = {Wiley},
      year = {1987},
    }
    
    @Book{unixpower,
      author = {M. et al Loukides},
      year = {2002},
      title = {Unix Power Tools},
      publisher = {O Reilly},
    }
    
    @Article{shellsort,
      author = {R. Sedgewick},
      title = {A new upper bound for Shell sort},
      journal = {J. Algorithms},
      edition = {7},
      pages = {159--173},
      year = {1986},
    }
    
    @Article{sort+minimal+storage,
      author = {R. C. Singleton},
      title = {An efficient algorithm for sorting with minimal storage: Algorithm 347},
      journal = {Communications of the ACM},
      edition = {12},
      pages = {185--187},
      year = {1969},
    }
    
    @Article{machar,
      author = {W. J. Cody},
      title = {{MACHAR}: A subroutine to dynamically determine machine parameters},
      edition = {14},
      number = {4},
      pages = {303--311},
      year = {1988},
      journal = {Transactions on Mathematical Software},
    }
    
    @Misc{ascii+unicode,
      author = {Markus Kuhn},
      title = {ASCII and Unicode quotation marks},
      url = {http://www.cl.cam.ac.uk/~mgk25/ucs/quotes.html},
    }
    
    @Misc{bash+cmd,
      author = {Mike Huffman},
      title = {Operating Systems, Unix Shell (bash) / Windows Console (CMD.EXE)},
      url = {http://www.mhuffman.com/notes/dos/bash_cmd.htm},
      year = {2003},
    }
    
    @Misc{wikipedia:collating+sequence,
      title = {Collating Sequence},
      year = {2009},
      url = {http://en.wikipedia.org/wiki/Collating_sequence},
    }
    
    @Misc{unicode+collation+algorithm,
      title = {Unicode Collation Algorithm},
      url = {http://unicode.org/reports/tr10/},
      author = {Mark Davis and Ken Whistler},
      year = {2008},
    }
    
    @Article{random:ahrens+dieter,
      title = {Extensions of Forsythes method for random sampling from the normal distribution},
      author = {J. H. Ahrens and U. Dieter},
      year = {1973},
      journal = {Mathematics of Computation},
      edition = {27},
      pages = {927--937},
    }
    
    @Article{random:box+muller,
      title = {A note on the generation of normal random deviates},
      author = {G. E. P. Box and M. E. Muller},
      year = {1958},
      journal = {Annals of Mathematical Statistics},
      edition = {29},
      pages = {610--611},
    }
    
    @Article{random:matteis+pagnutti,
      title = {Long-range Correlation Analysis of the Wichmann-Hill Random Number Generator},
      year = {1993},
      author = {A. {De Matteis} and S. Pagnutti},
      journal = {Statist. Comput.},
      edition = {3},
      pages = {67--70},
    }
    
    @Article{random:kinderman+ramage,
      title = {Computer generation of normal random variables},
      author = {A. J. Kinderman and J. G. Ramage},
      year = {1976},
      journal = {Journal of the American Statistical Association},
      edition = {71},
      pages = {893--896},
    }
    
    @Book{knuth:1997,
      title = {The Art of Computer Programming},
      author = {D. E. Knuth},
      year = {1997},
      volume = {2},
      edition = {Third edition},
      url = {http://www-cs-faculty.stanford.edu/~knuth/taocp.html},
      publisher = {Addison-Wesley Professional},
    }
    
    @Book{knuth:2002,
      title = {The Art of Computer Programming},
      author = {D. E. Knuth},
      year = {1997},
      volume = {2},
      edition = {Third edition, ninth printing},
      url = {http://Sunburn.Stanford.EDU/~knuth/news02.html},
      publisher = {Addison-Wesley Professional},
    }
    
    @Misc{random:marsaglia:1997,
      title = {A random number generator for C},
      author = {G Marsaglia},
      year = {1997},
      note = {Discussion paper, posting on {sci.stat.math} usenet group},
    }
    
    @Article{random:marsaglia+zaman:1998,
      title = {Some portable very-long-period random number generators},
      author = {G. Marsaglia and A. Zaman},
      year = {1994},
      journal = {Computers in Physics},
      edition = {8},
      pages = {117--121},
    }
    
    @Article{random:matsumoto+nishimura:1998,
      author = {M. Matsumoto and T. Nishimura},
      title = {Mersenne Twister: A 623-dimensionally equidistributed uniform pseudo-random number generator},
      journal = {ACM Transactions on Modeling and Computer Simulation},
      edition = {8},
      pages = {3--30},
      url = {http://www.math.keio.ac.jp/~matumoto/emt.html},
      year = {1998},
    }
    
    @Misc{random:superduper,
      author = {J. Reeds and S. Hubert and M. Abrahams},
      title = {C implementation of SuperDuper, University of California at Berkeley},
      year = {1982--4},
      note = {Personal communication from Jim Reeds to Ross Ihaka},
      institution = {University of California at Berkeley},
    }
    
    @Article{random:whichmann+hill:1982,
      title = {Algorithm {AS} 183: An Efficient and Portable Pseudo-random Number Generator},
      journal = {Applied Statistics},
      author = {B. A. Wichmann and I. D. Hill},
      edition = {31},
      pages = {188--190},
      note = {Remarks: 34, 198 and 35, 89},
      year = {1982},
    }
    
    @Misc{ansi754,
      title = {{ANSI/IEEE} 754 Floating-Point Standard},
      url = {http://grouper.ieee.org/groups/754/},
    }

